@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9626 2016-04-10 14:52:18Z Eric $
+# $Id: urls.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $
-# $Date: 2016-04-10 22:52:18 +0800 (週日, 10 四月 2016) $
-# $Revision: 9626 $
+# $Author: Kevin $
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 from django.conf.urls.defaults import patterns
 from django.conf.urls.defaults import include, url
@@ -26,7 +26,7 @@ from django.views.generic.simple import direct_to_template
 from django.contrib import admin
 admin.autodiscover()
 
-import settings
+from . import settings
 
 urlpatterns = patterns('')
 
