@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: CloudTest.py 10005 2017-06-03 09:30:38Z David $
+# $Id: CloudTest.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2017-06-03 17:30:38 +0800 (週六, 03 六月 2017) $
-# $Revision: 10005 $
+# $Author: Kevin $
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 import unittest
 import os
@@ -121,7 +121,7 @@ class MailWorkerTest(TestCase):
         stdout = worker.stdout.readline()
         lineNum = 1
         while stdout:
-            print stdout
+            print(stdout)
             if lineNum > 30:
                 break
             if '. Iuno.cloud.mail.tasks.send' in stdout:
