@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 9927 2017-04-29 14:17:02Z David $
+# $Id: Util.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (last)
-# $Date: 2017-04-29 22:17:02 +0800 (週六, 29 四月 2017) $
-# $Revision: 9927 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 """
 Utilities.
 """
@@ -26,7 +26,7 @@ def update(settingsDict, defaults, config=None):
     @param defaults Defaults dict to provide default value.
     @param config Reserved.
     """
-    for k, v in defaults.items():
+    for k, v in list(defaults.items()):
         if k not in settingsDict:
             settingsDict[k] = v
 
@@ -47,8 +47,8 @@ def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
     
     for k in keys:
         if k in os.environ:
-            print "%s found in environment variable, set to settings." % (
-                colored(k, 'yellow', attrs=['bold']))
+            print("%s found in environment variable, set to settings." % (
+                colored(k, 'yellow', attrs=['bold'])))
             
             v = os.environ[k]
             if evalKeys and k in evalKeys:
@@ -87,39 +87,36 @@ class VersionInfo(object):
     def __str__(self):
         return '%d.%d.%d.%d' % self.__key()
 
-    def __cmp__(self, other):
-        if isinstance(other, basestring):
-            return self.__cmp__(VersionInfo(other))
+    def __lt__(self, other):
+        if isinstance(other, str):
+            return self.__lt__(VersionInfo(other))
 
-        # Revision is an incremental number, it should compare first.
         if self.revision is not None and other.revision is not None:
-            if self.revision > other.revision:
-                return 1
-            elif self.revision < other.revision:
-                return -1
+            if self.revision < other.revision:
+                return True
 
         if self.major is not None and other.major is not None:
-            if self.major > other.major:
-                return 1
-            elif self.major < other.major:
-                return -1
+            if self.major < other.major:
+                return True
 
         if self.minor is not None and other.minor is not None:
-            if self.minor > other.minor:
-                return 1
-            elif self.minor < other.minor:
-                return -1
+            if self.minor < other.minor:
+                return True
 
         if self.build is not None and other.build is not None:
-            if self.build > other.build:
-                return 1
-            elif self.build < other.build:
-                return -1
+            if self.build < other.build:
+                return True
 
-        return 0 # Equal.
+        return False
+
+    def __gt__(self, other):
+        if self.__eq__(other) or self.__lt__(other):
+            return False
+        else:
+            return True
 
     def __eq__(self, other):
-        if isinstance(other, basestring):
+        if isinstance(other, str):
             return self.__eq__(VersionInfo(other))
         elif not isinstance(other, VersionInfo):
             return False
@@ -127,7 +124,7 @@ class VersionInfo(object):
             return self.__key() == other.__key()
 
     def __ne__(self, other):
-        if isinstance(other, basestring):
+        if isinstance(other, str):
             return self.__ne__(VersionInfo(other))
         else:
             return not self.__eq__(other)
