@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10321 2017-09-26 09:03:30Z David $
+# $Id: __init__.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,17 +11,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (last)
-# $Date: 2017-09-26 17:03:30 +0800 (Tue, 26 Sep 2017) $
-# $Revision: 10321 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
+
+from __future__ import print_function
 
 import os
 import sys
 import warnings
 import importlib
 
-from Patch import attachURLs, attachDebugURLs
-from Util import update, populateEnvToSettings
+from .Patch import attachURLs, attachDebugURLs
+from .Util import update, populateEnvToSettings
 
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
@@ -156,7 +158,7 @@ def checkImportPackage(packageName, settingsDict):
     @param settingsDict Settings dict.
     """
     try:
-        importlib.import_module(packageName)
+        return importlib.import_module(packageName)
     except ImportError:
         warnPackage(packageName)
         upperName = packageName.upper()
@@ -169,6 +171,7 @@ def checkImportPackage(packageName, settingsDict):
                 # Project use packageName settings but
                 # package is not available.
                 raise
+        return False
             
 def warnPackageDisable(packageName, settingsDict, defaults):
     """
@@ -220,7 +223,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     }
 
     # warnWithout('SERVER_MODE', settingsDict, serverModeDefaults)    
-    reversedServerModes = {v: k for k, v in serverModeDefaults.items() 
+    reversedServerModes = {v: k for k, v in list(serverModeDefaults.items()) 
                                 if k != 'SERVER_MODE'}
                                 
     update(settingsDict, serverModeDefaults)
@@ -232,10 +235,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     )
     
     if printDetail:
-        print colored('SERVER_MODE', 'yellow', attrs=['bold']),
-        print colored(" = ", 'white', attrs=['bold']),
-        print colored(reversedServerModes[settingsDict['SERVER_MODE']], 
-                    'cyan', attrs=['bold'])    
+        print(colored('SERVER_MODE', 'yellow', attrs=['bold']), end=' ')
+        print(colored(" = ", 'white', attrs=['bold']), end=' ')
+        print(colored(reversedServerModes[settingsDict['SERVER_MODE']], 
+                    'cyan', attrs=['bold']))    
     #=========================================================================
 
     #=========================================================================
@@ -250,7 +253,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     update(settingsDict, debugDefaults)
 
     # If environment variable specified DEBUG, we use it ignore SERVER_MODE.
-    populateEnvToSettings(debugDefaults.keys(), settingsDict, 
+    populateEnvToSettings(list(debugDefaults.keys()), settingsDict, 
         lambda k, v, s: s.update({
             k: {'true': True, 'false': False}[v.lower()],
         })
@@ -569,7 +572,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     
     update(settingsDict, emailDefaults)
     
-    populateEnvToSettings(emailDefaults.keys(), settingsDict, evalKeys=(
+    populateEnvToSettings(list(emailDefaults.keys()), settingsDict, evalKeys=(
         'EMAIL_PORT',
         'EMAIL_USE_TLS',
     ))
@@ -615,7 +618,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     }
 
     update(settingsDict, siteDefaults)
-    populateEnvToSettings(siteDefaults.keys(), settingsDict, evalKeys=(
+    populateEnvToSettings(list(siteDefaults.keys()), settingsDict, evalKeys=(
         'SITE_ID',
     ))    
     #=========================================================================
@@ -684,8 +687,13 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
     # Iuno.cloud.
-    checkImportPackage('Iuno.cloud', settingsDict)
-    import Iuno.cloud
+    try:
+        module = checkImportPackage('Iuno.cloud', settingsDict)
+    except ImportError:
+        pass
+    else:
+        if module:
+            import Iuno.cloud
     
     iunoCloudDefaults = {
         'IUNO_CLOUD_ENABLE': False,
@@ -709,13 +717,13 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'IUNO_CLOUD_SERVICES',
     ))
 
-    if settingsDict['IUNO_CLOUD_ENABLE']:
+    if settingsDict['IUNO_CLOUD_ENABLE'] and module:
         attachCloudKws = {'cache': True}
         if settingsDict['IUNO_CLOUD_SERVICES'] is not None:
             attachCloudKws['services'] = settingsDict['IUNO_CLOUD_SERVICES']
 
         cloudServiceSettings = {}
-        for k in iunoCloudDefaults.keys():
+        for k in list(iunoCloudDefaults.keys()):
             if k.startswith('IUNO_CLOUD_') and k.endswith('_SETTINGS'):
                 srv = k[len('IUNO_CLOUD_'):-len('_SETTINGS')].lower()
                 if settingsDict[k] is not None:
@@ -757,8 +765,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
         update(settingsDict, iunoMemberDefaults)
         
-        populateEnvToSettings(iunoMemberDefaults.keys(), settingsDict, 
-                            evalKeys=iunoMemberDefaults.keys())
+        populateEnvToSettings(list(iunoMemberDefaults.keys()), settingsDict, 
+                            evalKeys=list(iunoMemberDefaults.keys()))
 
         if settingsDict['IUNO_MEMBER_ENABLE']:
             Iuno.member.attachSettings(
@@ -790,8 +798,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
         update(settingsDict, iunoShopDefaults)
         
-        populateEnvToSettings(iunoShopDefaults.keys(), settingsDict, 
-                            evalKeys=iunoShopDefaults.keys())
+        populateEnvToSettings(list(iunoShopDefaults.keys()), settingsDict, 
+                            evalKeys=list(iunoShopDefaults.keys()))
 
         if settingsDict['IUNO_SHOP_ENABLE']:
             Iuno.shop.attachSettings(
