@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: __init__.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (週五, 25 九月 2015) $
-# $Revision: 9439 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -21,7 +21,7 @@ from __future__ import absolute_import
 import os
 import time
 import logging as pyLogging
-import cPickle as pickle
+import pickle as pickle
 
 import singletonmixin
 
@@ -186,7 +186,7 @@ def attachSettings(settingsLocals, services=(
                 servicePackage = classForName(service)
             else: # Default Iuno.cloud services.
                 servicePackage = classForName('Iuno.cloud.%s' % service)
-        except ImportError, ex:
+        except ImportError as ex:
             logger.warn('%s can not be imported: %s' % (service, str(ex)))
             continue
 
@@ -204,7 +204,7 @@ def attachSettings(settingsLocals, services=(
         preferred = config.get('preferred', None)
 
         backends = getBackends(servicePackage, backendClasses,
-                               preferred=preferred.keys()
+                               preferred=list(preferred.keys())
                                          if preferred else None,
                                context=settingsLocals,
                                config=config)
@@ -311,7 +311,7 @@ def tryGet(methodName, backends, preferred=None, *args, **kws):
     """
     if preferred:
         values = dict([(b.name, b) for b in backends])
-        names = preferredSort(values.keys(), preferred)
+        names = preferredSort(list(values.keys()), preferred)
         backends = [values[n] for n in names]
 
     for backend in backends:
