@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Amazon.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: Amazon.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 import os
 
@@ -63,7 +63,7 @@ class Backend(BaseBackend):
 
         d = self._readCache('idDnsDict')
         if d:
-            self.logger.info('INSTANCES: %s (from cache)' % str(d.keys()))
+            self.logger.info('INSTANCES: %s (from cache)' % str(list(d.keys())))
         else:
             regions = self.getRegions()
             reservations = []
@@ -81,10 +81,10 @@ class Backend(BaseBackend):
 
             d = dict([(i.id, i.public_dns_name) for i in instances])
 
-            self.logger.info('INSTANCES: %s' % str(d.keys()))
+            self.logger.info('INSTANCES: %s' % str(list(d.keys())))
             self._writeCache('idDnsDict', d, expire=86400) # expire 1 day.
 
-        values = d.keys()
+        values = list(d.keys())
 
         preferredSort(values, preferred)
         return [d[v] for v in values]
