@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: __init__.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (週五, 25 九月 2015) $
-# $Revision: 9439 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 import logging
 
@@ -121,7 +121,7 @@ def attach(project='test', level=None, format=None,
     }
     
     backends = getBackends(globals(), backendClasses,
-                           preferred=preferred.keys() if preferred else None,
+                           preferred=list(preferred.keys()) if preferred else None,
                            config=config)
 
     hostInfo = tryGet('getSentryInfo', backends, preferred, config)
@@ -161,7 +161,7 @@ def attach(project='test', level=None, format=None,
         logger = logging.getLogger()        
     else:
         logger = logging.getLogger(attachLoggerName)
-        if handler.__class__ in map(type, logger.handlers):
+        if handler.__class__ in list(map(type, logger.handlers)):
             return handler
 
         logger.addHandler(handler)
