@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Nuwa.py 10419 2017-10-29 15:30:56Z Kevin $
+# $Id: Nuwa.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2017-10-29 23:30:56 +0800 (Sun, 29 Oct 2017) $
-# $Revision: 10419 $
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 from Iuno.cloud.backend import BaseBackend
 from Iuno.cloud.logging.backend import BackendMixin
@@ -27,9 +27,9 @@ class Backend(BaseBackend, BackendMixin):
     SENTRY_CONFIGS = {
         'sentry.nuwainfo.com': {
             'test': {
-                'SENTRY_DSN': ('https://28dd3e48e1f144e6b595d120e331662e:'
-                               'dbeda9f0462945938ce908b1727a7323@'
-                               'sentry.nuwainfo.com/8'),
+                'SENTRY_DSN': ('threaded+https://'
+                    '28dd3e48e1f144e6b595d120e331662e:'
+                    'dbeda9f0462945938ce908b1727a7323@sentry.nuwainfo.com/8'),
             },
             'mail': {
                 'SENTRY_DSN': ('threaded+https://'
