@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10005 2017-06-03 09:30:38Z David $
+# $Id: __init__.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (last)
-# $Date: 2017-06-03 17:30:38 +0800 (週六, 03 六月 2017) $
-# $Revision: 10005 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 """
 Celery tasks which should be run at cloud worker.
 """
@@ -82,7 +82,7 @@ def send(email_messages, fail_silently=False, *args, **kws):
                                 message.from_email, message.recipients(),
                                 message.subject, fileName))
                     break
-        except Exception, e:
+        except Exception as e:
             try:
                 logger.debug(('EMail sent [FROM]: %s [TO]: %s '
                               '[SUBJECT]: %s [BODY HTML]: FAILED => %s.') % (
