@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10096 2017-07-11 11:03:58Z David $
+# $Id: urls.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,13 +11,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (last)
-# $Date: 2017-07-11 19:03:58 +0800 (週二, 11 七月 2017) $
-# $Revision: 10096 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 from django.conf.urls import include, url
 
-from views import (
+from .views import (
     SignupView, LoginView, ConfirmEmailView, ChangePasswordView, LogoutView,
     PasswordResetView, PasswordResetTokenView, SettingsView, DeleteView
 )
