@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
+# $Id: __init__.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (last)
-# $Date: 2017-05-04 18:37:30 +0800 (週四, 04 五月 2017) $
-# $Revision: 9947 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 import os
 import sys
@@ -157,7 +157,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     # see #2784
     addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
-            'oscar.defaults', globals(), locals(), [], -1
+            'oscar.defaults', globals(), locals(), [], 0
         ).__dict__['defaults']
     for attr in dir(oscarDefaultsPackages):
         addOscarDefaultsPackages[attr] = getattr(
@@ -227,7 +227,7 @@ def attachPaypalURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    import views
+    from Iuno.shop import views
 
     from django.conf.urls import url, patterns, include
     from paypal.express.dashboard.app import application
