@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: UtilTest.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: UtilTest.py 10898 2018-03-19 09:19:26Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: Kevin $ (last)
+# $Date: 2018-03-19 17:19:26 +0800 (週一, 19 三月 2018) $
+# $Revision: 10898 $
 
 import unittest
 
@@ -52,12 +52,12 @@ class UtilTest(unittest.TestCase):
         self.assertTrue(Util.VersionInfo('0.1.1.*') == '0.1.1.?')
 
         self.assertEqual(str(v1), '0.1.0.2137')
-        self.assertEqual(unicode(v2), u'0.2.0.4444')
+        self.assertEqual(str(v2), '0.2.0.4444')
 
-        self.assertEqual(v1, u'0.1.0.2137')
+        self.assertEqual(v1, '0.1.0.2137')
 
         self.assertEqual('v: %s' % v1, 'v: 0.1.0.2137')
-        self.assertEqual(u'v: %s' % v3, u'v: 0.2.1.56789')
+        self.assertEqual('v: %s' % v3, 'v: 0.2.1.56789')
 
 if __name__ == '__main__':
     unittest.main()
